@@ -14,18 +14,19 @@ from weakref import WeakValueDictionary
 
 import numpy as np
 
-from . import _path, rcParams
+from . import _path, cbook, rcParams
 from .cbook import _to_unmasked_float_array, simple_linear_interpolation
 
 
-class Path(object):
+class Path:
     """
-    :class:`Path` represents a series of possibly disconnected,
-    possibly closed, line and curve segments.
+    A series of possibly disconnected, possibly closed, line and curve
+    segments.
 
     The underlying storage is made up of two parallel numpy arrays:
-      - *vertices*: an Nx2 float array of vertices
-      - *codes*: an N-length uint8 array of vertex types
+
+    - *vertices*: an Nx2 float array of vertices
+    - *codes*: an N-length uint8 array of vertex types, or None
 
     These two arrays always have the same length in the first
     dimension.  For example, to represent a cubic curve, you must
@@ -33,37 +34,37 @@ class Path(object):
 
     The code types are:
 
-       - ``STOP``   :  1 vertex (ignored)
-           A marker for the end of the entire path (currently not
-           required and ignored)
+    - ``STOP``   :  1 vertex (ignored)
+        A marker for the end of the entire path (currently not required and
+        ignored)
 
-       - ``MOVETO`` :  1 vertex
-            Pick up the pen and move to the given vertex.
+    - ``MOVETO`` :  1 vertex
+        Pick up the pen and move to the given vertex.
 
-       - ``LINETO`` :  1 vertex
-            Draw a line from the current position to the given vertex.
+    - ``LINETO`` :  1 vertex
+        Draw a line from the current position to the given vertex.
 
-       - ``CURVE3`` :  1 control point, 1 endpoint
-          Draw a quadratic Bezier curve from the current position,
-          with the given control point, to the given end point.
+    - ``CURVE3`` :  1 control point, 1 endpoint
+        Draw a quadratic Bezier curve from the current position, with the given
+        control point, to the given end point.
 
-       - ``CURVE4`` :  2 control points, 1 endpoint
-          Draw a cubic Bezier curve from the current position, with
-          the given control points, to the given end point.
+    - ``CURVE4`` :  2 control points, 1 endpoint
+        Draw a cubic Bezier curve from the current position, with the given
+        control points, to the given end point.
 
-       - ``CLOSEPOLY`` : 1 vertex (ignored)
-          Draw a line segment to the start point of the current
-          polyline.
+    - ``CLOSEPOLY`` : 1 vertex (ignored)
+        Draw a line segment to the start point of the current polyline.
 
-    Users of Path objects should not access the vertices and codes
-    arrays directly.  Instead, they should use :meth:`iter_segments`
-    or :meth:`cleaned` to get the vertex/code pairs.  This is important,
-    since many :class:`Path` objects, as an optimization, do not store a
-    *codes* at all, but have a default one provided for them by
-    :meth:`iter_segments`.
+    If *codes* is None, it is interpreted as a ``MOVETO`` followed by a series
+    of ``LINETO``.
 
-    Some behavior of Path objects can be controlled by rcParams. See
-    the rcParams whose keys contain 'path.'.
+    Users of Path objects should not access the vertices and codes arrays
+    directly.  Instead, they should use `iter_segments` or `cleaned` to get the
+    vertex/code pairs.  This helps, in particular, to consistently handle the
+    case of *codes* being None.
+
+    Some behavior of Path objects can be controlled by rcParams. See the
+    rcParams whose keys start with 'path.'.
 
     .. note::
 
@@ -71,16 +72,17 @@ class Path(object):
         immutable -- there are a number of optimizations and assumptions
         made up front in the constructor that will not change when the
         data changes.
-
     """
 
+    code_type = np.uint8
+
     # Path codes
-    STOP = 0         # 1 vertex
-    MOVETO = 1       # 1 vertex
-    LINETO = 2       # 1 vertex
-    CURVE3 = 3       # 2 vertices
-    CURVE4 = 4       # 3 vertices
-    CLOSEPOLY = 79   # 1 vertex
+    STOP = code_type(0)         # 1 vertex
+    MOVETO = code_type(1)       # 1 vertex
+    LINETO = code_type(2)       # 1 vertex
+    CURVE3 = code_type(3)       # 2 vertices
+    CURVE4 = code_type(4)       # 3 vertices
+    CLOSEPOLY = code_type(79)   # 1 vertex
 
     #: A dictionary mapping Path codes to the number of vertices that the
     #: code expects.
@@ -91,8 +93,6 @@ class Path(object):
                              CURVE4: 3,
                              CLOSEPOLY: 1}
 
-    code_type = np.uint8
-
     def __init__(self, vertices, codes=None, _interpolation_steps=1,
                  closed=False, readonly=False):
         """
@@ -100,15 +100,15 @@ class Path(object):
 
         Parameters
         ----------
-        vertices : array_like
-            The ``(n, 2)`` float array, masked array or sequence of pairs
+        vertices : array-like
+            The ``(N, 2)`` float array, masked array or sequence of pairs
             representing the vertices of the path.
 
             If *vertices* contains masked values, they will be converted
             to NaNs which are then handled correctly by the Agg
             PathIterator and other consumers of path data, such as
             :meth:`iter_segments`.
-        codes : {None, array_like}, optional
+        codes : array-like or None, optional
             n-length array integers representing the codes of the path.
             If not None, codes must be the same length as vertices.
             If None, *vertices* will be treated as a series of line segments.
@@ -157,37 +157,32 @@ class Path(object):
             self._readonly = False
 
     @classmethod
-    def _fast_from_codes_and_verts(cls, verts, codes, internals=None):
+    def _fast_from_codes_and_verts(cls, verts, codes, internals_from=None):
         """
-        Creates a Path instance without the expense of calling the constructor
+        Creates a Path instance without the expense of calling the constructor.
 
         Parameters
         ----------
         verts : numpy array
         codes : numpy array
-        internals : dict or None
-            The attributes that the resulting path should have.
-            Allowed keys are ``readonly``, ``should_simplify``,
-            ``simplify_threshold``, ``has_nonfinite`` and
-            ``interpolation_steps``.
-
+        internals_from : Path or None
+            If not None, another `Path` from which the attributes
+            ``should_simplify``, ``simplify_threshold``, and
+            ``interpolation_steps`` will be copied.  Note that ``readonly`` is
+            never copied, and always set to ``False`` by this constructor.
         """
-        internals = internals or {}
         pth = cls.__new__(cls)
         pth._vertices = _to_unmasked_float_array(verts)
         pth._codes = codes
-        pth._readonly = internals.pop('readonly', False)
-        pth.should_simplify = internals.pop('should_simplify', True)
-        pth.simplify_threshold = (
-            internals.pop('simplify_threshold',
-                          rcParams['path.simplify_threshold'])
-        )
-        pth._has_nonfinite = internals.pop('has_nonfinite', False)
-        pth._interpolation_steps = internals.pop('interpolation_steps', 1)
-        if internals:
-            raise ValueError('Unexpected internals provided to '
-                             '_fast_from_codes_and_verts: '
-                             '{0}'.format('\n *'.join(internals)))
+        pth._readonly = False
+        if internals_from is not None:
+            pth._should_simplify = internals_from._should_simplify
+            pth._simplify_threshold = internals_from._simplify_threshold
+            pth._interpolation_steps = internals_from._interpolation_steps
+        else:
+            pth._should_simplify = True
+            pth._simplify_threshold = rcParams['path.simplify_threshold']
+            pth._interpolation_steps = 1
         return pth
 
     def _update_values(self):
@@ -198,7 +193,6 @@ class Path(object):
             len(self._vertices) >= 128 and
             (self._codes is None or np.all(self._codes <= Path.LINETO))
         )
-        self._has_nonfinite = not np.isfinite(self._vertices).all()
 
     @property
     def vertices(self):
@@ -245,12 +239,14 @@ class Path(object):
     def simplify_threshold(self, threshold):
         self._simplify_threshold = threshold
 
+    @cbook.deprecated(
+        "3.1", alternative="not np.isfinite(self.vertices).all()")
     @property
     def has_nonfinite(self):
         """
         `True` if the vertices array has nonfinite values.
         """
-        return self._has_nonfinite
+        return not np.isfinite(self._vertices).all()
 
     @property
     def should_simplify(self):
@@ -316,7 +312,7 @@ class Path(object):
         stride = numsides + 1
         nverts = numpolys * stride
         verts = np.zeros((nverts, 2))
-        codes = np.ones(nverts, int) * cls.LINETO
+        codes = np.full(nverts, cls.LINETO, dtype=cls.code_type)
         codes[0::stride] = cls.MOVETO
         codes[numsides::stride] = cls.CLOSEPOLY
         for i in range(numsides):
@@ -359,46 +355,41 @@ class Path(object):
                       snap=False, stroke_width=1.0, simplify=None,
                       curves=True, sketch=None):
         """
-        Iterates over all of the curve segments in the path.  Each
-        iteration returns a 2-tuple (*vertices*, *code*), where
-        *vertices* is a sequence of 1 - 3 coordinate pairs, and *code* is
-        one of the :class:`Path` codes.
+        Iterates over all of the curve segments in the path.  Each iteration
+        returns a 2-tuple ``(vertices, code)``, where ``vertices`` is a
+        sequence of 1-3 coordinate pairs, and ``code`` is a `Path` code.
 
-        Additionally, this method can provide a number of standard
-        cleanups and conversions to the path.
+        Additionally, this method can provide a number of standard cleanups and
+        conversions to the path.
 
         Parameters
         ----------
-        transform : None or :class:`~matplotlib.transforms.Transform` instance
-            If not None, the given affine transformation will
-            be applied to the path.
-        remove_nans : {False, True}, optional
-            If True, will remove all NaNs from the path and
-            insert MOVETO commands to skip over them.
-        clip : None or sequence, optional
+        transform : None or :class:`~matplotlib.transforms.Transform`
+            If not None, the given affine transformation will be applied to the
+            path.
+        remove_nans : bool, optional
+            Whether to remove all NaNs from the path and skip over them using
+            MOVETO commands.
+        clip : None or (float, float, float, float), optional
             If not None, must be a four-tuple (x1, y1, x2, y2)
             defining a rectangle in which to clip the path.
         snap : None or bool, optional
-            If None, auto-snap to pixels, to reduce
-            fuzziness of rectilinear lines.  If True, force snapping, and
-            if False, don't snap.
+            If True, snap all nodes to pixels; if False, don't snap them.
+            If None, perform snapping if the path contains only segments
+            parallel to the x or y axes, and no more than 1024 of them.
         stroke_width : float, optional
-            The width of the stroke being drawn.  Needed
-             as a hint for the snapping algorithm.
+            The width of the stroke being drawn (used for path snapping).
         simplify : None or bool, optional
-            If True, perform simplification, to remove
-             vertices that do not affect the appearance of the path.  If
-             False, perform no simplification.  If None, use the
-             should_simplify member variable.  See also the rcParams
-             path.simplify and path.simplify_threshold.
-        curves : {True, False}, optional
-            If True, curve segments will be returned as curve
-            segments.  If False, all curves will be converted to line
-            segments.
+            Whether to simplify the path by removing vertices
+            that do not affect its appearance.  If None, use the
+            :attr:`should_simplify` attribute.  See also :rc:`path.simplify`
+            and :rc:`path.simplify_threshold`.
+        curves : bool, optional
+            If True, curve segments will be returned as curve segments.
+            If False, all curves will be converted to line segments.
         sketch : None or sequence, optional
             If not None, must be a 3-tuple of the form
-            (scale, length, randomness), representing the sketch
-            parameters.
+            (scale, length, randomness), representing the sketch parameters.
         """
         if not len(self):
             return
@@ -408,78 +399,83 @@ class Path(object):
                                snap=snap, stroke_width=stroke_width,
                                simplify=simplify, curves=curves,
                                sketch=sketch)
-        vertices = cleaned.vertices
-        codes = cleaned.codes
-        len_vertices = vertices.shape[0]
 
         # Cache these object lookups for performance in the loop.
         NUM_VERTICES_FOR_CODE = self.NUM_VERTICES_FOR_CODE
         STOP = self.STOP
 
-        i = 0
-        while i < len_vertices:
-            code = codes[i]
+        vertices = iter(cleaned.vertices)
+        codes = iter(cleaned.codes)
+        for curr_vertices, code in zip(vertices, codes):
             if code == STOP:
-                return
-            else:
-                num_vertices = NUM_VERTICES_FOR_CODE[code]
-                curr_vertices = vertices[i:i+num_vertices].flatten()
-                yield curr_vertices, code
-                i += num_vertices
+                break
+            extra_vertices = NUM_VERTICES_FOR_CODE[code] - 1
+            if extra_vertices:
+                for i in range(extra_vertices):
+                    next(codes)
+                    curr_vertices = np.append(curr_vertices, next(vertices))
+            yield curr_vertices, code
 
     def cleaned(self, transform=None, remove_nans=False, clip=None,
                 quantize=False, simplify=False, curves=False,
                 stroke_width=1.0, snap=False, sketch=None):
         """
-        Cleans up the path according to the parameters returning a new
-        Path instance.
-
-        .. seealso::
-
-            See :meth:`iter_segments` for details of the keyword arguments.
-
-        Returns
-        -------
-        Path instance with cleaned up vertices and codes.
+        Return a new Path with vertices and codes cleaned according to the
+        parameters.
 
+        See Also
+        --------
+        Path.iter_segments : for details of the keyword arguments.
         """
-        vertices, codes = _path.cleanup_path(self, transform,
-                                             remove_nans, clip,
-                                             snap, stroke_width,
-                                             simplify, curves, sketch)
-        internals = {'should_simplify': self.should_simplify and not simplify,
-                     'has_nonfinite': self.has_nonfinite and not remove_nans,
-                     'simplify_threshold': self.simplify_threshold,
-                     'interpolation_steps': self._interpolation_steps}
-        return Path._fast_from_codes_and_verts(vertices, codes, internals)
+        vertices, codes = _path.cleanup_path(
+            self, transform, remove_nans, clip, snap, stroke_width, simplify,
+            curves, sketch)
+        pth = Path._fast_from_codes_and_verts(vertices, codes, self)
+        if not simplify:
+            pth._should_simplify = False
+        return pth
 
     def transformed(self, transform):
         """
         Return a transformed copy of the path.
 
-        .. seealso::
-
-            :class:`matplotlib.transforms.TransformedPath`
-                A specialized path class that will cache the
-                transformed result and automatically update when the
-                transform changes.
+        See Also
+        --------
+        matplotlib.transforms.TransformedPath
+            A specialized path class that will cache the transformed result and
+            automatically update when the transform changes.
         """
         return Path(transform.transform(self.vertices), self.codes,
                     self._interpolation_steps)
 
     def contains_point(self, point, transform=None, radius=0.0):
         """
-        Returns whether the (closed) path contains the given point.
+        Return whether the (closed) path contains the given point.
 
-        If *transform* is not ``None``, the path will be transformed before
-        performing the test.
+        Parameters
+        ----------
+        point : (float, float)
+            The point (x, y) to check.
+        transform : `matplotlib.transforms.Transform`, optional
+            If not ``None``, *point* will be compared to ``self`` transformed
+            by *transform*; i.e. for a correct check, *transform* should
+            transform the path into the coordinate system of *point*.
+        radius : float, default: 0
+            Add an additional margin on the path in coordinates of *point*.
+            The path is extended tangentially by *radius/2*; i.e. if you would
+            draw the path with a linewidth of *radius*, all points on the line
+            would still be considered to be contained in the area. Conversely,
+            negative values shrink the area: Points on the imaginary line
+            will be considered outside the area.
 
-        *radius* allows the path to be made slightly larger or smaller.
+        Returns
+        -------
+        bool
         """
         if transform is not None:
             transform = transform.frozen()
         # `point_in_path` does not handle nonlinear transforms, so we
-        # transform the path ourselves.  If `transform` is affine, letting
+        # transform the path ourselves.  If *transform* is affine, letting
         # `point_in_path` handle the transform avoids allocating an extra
         # buffer.
         if transform and not transform.is_affine:
@@ -489,13 +485,27 @@ class Path(object):
 
     def contains_points(self, points, transform=None, radius=0.0):
         """
-        Returns a bool array which is ``True`` if the (closed) path contains
-        the corresponding point.
+        Return whether the (closed) path contains the given point.
 
-        If *transform* is not ``None``, the path will be transformed before
-        performing the test.
+        Parameters
+        ----------
+        points : (N, 2) array
+            The points to check. Columns contain x and y values.
+        transform : `matplotlib.transforms.Transform`, optional
+            If not ``None``, *points* will be compared to ``self`` transformed
+            by *transform*; i.e. for a correct check, *transform* should
+            transform the path into the coordinate system of *points*.
+        radius : float, default: 0.
+            Add an additional margin on the path in coordinates of *points*.
+            The path is extended tangentially by *radius/2*; i.e. if you would
+            draw the path with a linewidth of *radius*, all points on the line
+            would still be considered to be contained in the area. Conversely,
+            negative values shrink the area: Points on the imaginary line
+            will be considered outside the area.
 
-        *radius* allows the path to be made slightly larger or smaller.
+        Returns
+        -------
+        length-N bool array
         """
         if transform is not None:
             transform = transform.frozen()
@@ -515,8 +525,7 @@ class Path(object):
 
     def get_extents(self, transform=None):
         """
-        Returns the extents (*xmin*, *ymin*, *xmax*, *ymax*) of the
-        path.
+        Returns the extents (*xmin*, *ymin*, *xmax*, *ymax*) of the path.
 
         Unlike computing the extents on the *vertices* alone, this
         algorithm will take into account the curves and deal with
@@ -543,8 +552,7 @@ class Path(object):
 
     def intersects_bbox(self, bbox, filled=True):
         """
-        Returns *True* if this path intersects a given
-        :class:`~matplotlib.transforms.Bbox`.
+        Returns whether this path intersects a given `~.transforms.Bbox`.
 
         *filled*, when True, treats the path as if it was filled.
         That is, if the path completely encloses the bounding box,
@@ -566,7 +574,8 @@ class Path(object):
         vertices = simple_linear_interpolation(self.vertices, steps)
         codes = self.codes
         if codes is not None:
-            new_codes = Path.LINETO * np.ones(((len(codes) - 1) * steps + 1, ))
+            new_codes = np.full((len(codes) - 1) * steps + 1, Path.LINETO,
+                                dtype=self.code_type)
             new_codes[0::steps] = codes
         else:
             new_codes = None
@@ -621,8 +630,7 @@ class Path(object):
     @classmethod
     def unit_rectangle(cls):
         """
-        Return a :class:`Path` instance of the unit rectangle
-        from (0, 0) to (1, 1).
+        Return a `Path` instance of the unit rectangle from (0, 0) to (1, 1).
         """
         if cls._unit_rectangle is None:
             cls._unit_rectangle = \
@@ -706,7 +714,6 @@ class Path(object):
         Return the readonly :class:`Path` of the unit circle.
 
         For most cases, :func:`Path.circle` will be what you want.
-
         """
         if cls._unit_circle is None:
             cls._unit_circle = cls.circle(center=(0, 0), radius=1,
@@ -716,7 +723,7 @@ class Path(object):
     @classmethod
     def circle(cls, center=(0., 0.), radius=1., readonly=False):
         """
-        Return a Path representing a circle of a given radius and center.
+        Return a `Path` representing a circle of a given radius and center.
 
         Parameters
         ----------
@@ -730,13 +737,10 @@ class Path(object):
 
         Notes
         -----
-        The circle is approximated using cubic Bezier curves.  This
-        uses 8 splines around the circle using the approach presented
-        here:
+        The circle is approximated using 8 cubic Bezier curves, as described in
 
           Lancaster, Don.  `Approximating a Circle or an Ellipse Using Four
           Bezier Cubic Splines <http://www.tinaja.com/glib/ellipse4.pdf>`_.
-
         """
         MAGIC = 0.2652031
         SQRTHALF = np.sqrt(0.5)
@@ -789,13 +793,9 @@ class Path(object):
     @classmethod
     def unit_circle_righthalf(cls):
         """
-        Return a :class:`Path` of the right half
-        of a unit circle. The circle is approximated using cubic Bezier
-        curves.  This uses 4 splines around the circle using the approach
-        presented here:
+        Return a `Path` of the right half of a unit circle.
 
-          Lancaster, Don.  `Approximating a Circle or an Ellipse Using Four
-          Bezier Cubic Splines <http://www.tinaja.com/glib/ellipse4.pdf>`_.
+        See `Path.circle` for the reference on the approximation used.
         """
         if cls._unit_circle_righthalf is None:
             MAGIC = 0.2652031
@@ -825,7 +825,7 @@ class Path(object):
 
                 float)
 
-            codes = cls.CURVE4 * np.ones(14)
+            codes = np.full(14, cls.CURVE4, dtype=cls.code_type)
             codes[0] = cls.MOVETO
             codes[-1] = cls.CLOSEPOLY
 
@@ -835,8 +835,8 @@ class Path(object):
     @classmethod
     def arc(cls, theta1, theta2, n=None, is_wedge=False):
         """
-        Return an arc on the unit circle from angle
-        *theta1* to angle *theta2* (in degrees).
+        Return the unit circle arc from angles *theta1* to *theta2* (in
+        degrees).
 
         *theta2* is unwrapped to produce the shortest arc within 360 degrees.
         That is, if *theta2* > *theta1* + 360, the arc will be from *theta1* to
@@ -887,7 +887,7 @@ class Path(object):
         if is_wedge:
             length = n * 3 + 4
             vertices = np.zeros((length, 2), float)
-            codes = cls.CURVE4 * np.ones((length, ), cls.code_type)
+            codes = np.full(length, cls.CURVE4, dtype=cls.code_type)
             vertices[1] = [xA[0], yA[0]]
             codes[0:2] = [cls.MOVETO, cls.LINETO]
             codes[-2:] = [cls.LINETO, cls.CLOSEPOLY]
@@ -896,7 +896,7 @@ class Path(object):
         else:
             length = n * 3 + 1
             vertices = np.empty((length, 2), float)
-            codes = cls.CURVE4 * np.ones((length, ), cls.code_type)
+            codes = np.full(length, cls.CURVE4, dtype=cls.code_type)
             vertices[0] = [xA[0], yA[0]]
             codes[0] = cls.MOVETO
             vertex_offset = 1
@@ -914,8 +914,8 @@ class Path(object):
     @classmethod
     def wedge(cls, theta1, theta2, n=None):
         """
-        Return a wedge of the unit circle from angle
-        *theta1* to angle *theta2* (in degrees).
+        Return the unit circle wedge from angles *theta1* to *theta2* (in
+        degrees).
 
         *theta2* is unwrapped to produce the shortest wedge within 360 degrees.
         That is, if *theta2* > *theta1* + 360, the wedge will be from *theta1*
@@ -924,6 +924,8 @@ class Path(object):
         If *n* is provided, it is the number of spline segments to make.
         If *n* is not provided, the number of spline segments is
         determined based on the delta between *theta1* and *theta2*.
+
+        See `Path.arc` for the reference on the approximation used.
         """
         return cls.arc(theta1, theta2, n, True)
 
@@ -957,26 +959,25 @@ class Path(object):
 
 def get_path_collection_extents(
         master_transform, paths, transforms, offsets, offset_transform):
-    """
-    Given a sequence of :class:`Path` objects,
-    :class:`~matplotlib.transforms.Transform` objects and offsets, as
-    found in a :class:`~matplotlib.collections.PathCollection`,
-    returns the bounding box that encapsulates all of them.
+    r"""
+    Given a sequence of `Path`\s, `~.Transform`\s objects, and offsets, as
+    found in a `~.PathCollection`, returns the bounding box that encapsulates
+    all of them.
 
-    *master_transform* is a global transformation to apply to all paths
-
-    *paths* is a sequence of :class:`Path` instances.
-
-    *transforms* is a sequence of
-    :class:`~matplotlib.transforms.Affine2D` instances.
-
-    *offsets* is a sequence of (x, y) offsets (or an Nx2 array)
-
-    *offset_transform* is a :class:`~matplotlib.transforms.Affine2D`
-    to apply to the offsets before applying the offset to the path.
+    Parameters
+    ----------
+    master_transform : `~.Transform`
+        Global transformation applied to all paths.
+    paths : list of `Path`
+    transform : list of `~.Affine2D`
+    offsets : (N, 2) array-like
+    offset_transform : `~.Affine2D`
+        Transform applied to the offsets before offsetting the path.
 
+    Notes
+    -----
     The way that *paths*, *transforms* and *offsets* are combined
-    follows the same method as for collections.  Each is iterated over
+    follows the same method as for collections:  Each is iterated over
     independently, so if you have 3 paths, 2 transforms and 1 offset,
     their combinations are as follows:
 
@@ -990,6 +991,7 @@ def get_path_collection_extents(
         offsets, offset_transform))
 
 
+@cbook.deprecated("3.1", alternative="get_paths_collection_extents")
 def get_paths_extents(paths, transforms=[]):
     """
     Given a sequence of :class:`Path` objects and optional
